@@ -3,7 +3,8 @@
 #' Get summary graphs of catches, recruitment, fishing pressure, and spawning
 #' stock biomass.
 #'
-#' @param key the unique identifier of the stock assessment
+#' @param assessmentKey the unique identifier of the stock assessment
+#' @param ... to allow scope for back compatability
 #'
 #' @return An array representing a bitmap.
 #'
@@ -17,45 +18,37 @@
 #' @author Colin Millar and Scott Large.
 #'
 #' @examples
-#' key <- findKey("cod", 2015)
-#' graphs <- getSAGGraphs(key[1])
+#' assessmentKey <- findAssessmentKey("cod", 2015)
+#' graphs <- getSAGGraphs(assessmentKey[1])
 #' plot(graphs)
 #'
 #' @export
 
-getSAGGraphs <- function(key) {
-  # check web services are running
-  if (!checkSAGWebserviceOK()) return (FALSE)
+getSAGGraphs <- function(assessmentKey, ...) {
+  assessmentKey <- checkKeyArg(assessmentKey = assessmentKey, ...)
 
   # only 1 key can be used
-  if (length(key) > 1) {
-    key <- key[1]
-    warning("key has length > 1 and only the first element will be used")
+  if (length(assessmentKey) > 1) {
+    assessmentKey <- assessmentKey[1]
+    warning("assessmentKey has length > 1 and only the first key will be used")
   }
 
-  # check graph type requested
+  # which graph types to get
   types <- c("Landings",
              "Recruitment",
              "FishingMortality",
              "SpawningStockBiomass")
 
-  # read and parse text from API
-  url <-
-    sprintf(
-      "http://sg.ices.dk/StandardGraphsWebServices.asmx/get%sGraph?key=%i",
-      types, key)
-
-  # read urls
-  out <- lapply(url, readSAG)
-
-  # parse text
-  out <- lapply(out, parseGraph)
-
-  # drop NULLs
-  out <- out[!sapply(out, is.null)]
+  # call webservices, built as: get<types>Graph
+  out <-
+    sapply(types,
+           function(x)
+               do.call(sprintf("get%sGraph", x),
+                     args = list(assessmentKey = assessmentKey)))
 
   # set class
   class(out) <- c("ices_standardgraph_list", class(out))
 
+  # return
   out
 }
